/* Copyright 2010, 2011, 2012 Stefan Zoerner
 * 
 * This file is part of DokChess.
 * 
 * DokChess is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DokChess is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with DokChess.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.dokchess.regeln;

import java.util.Collection;

import de.dokchess.allgemein.Farbe;
import de.dokchess.allgemein.Stellung;
import de.dokchess.allgemein.Zug;

public interface Spielregeln {

	/**
	 * Liefert die Menge aller gultigen Zuge fur den aktuellen Spieler. Der
	 * Spieler am Zug wird aus der Stellung ermittelt. Im Falle eines Matt oder
	 * Patt wird eine leere Collection zuruckgeliefert, das Ergebnis ist also
	 * nie null.
	 * 
	 * @param stellung
	 *            zu betrachtende Spielsituation
	 * 
	 * @return Menge, der Zuge, gegebenenfalls leer
	 */
	Collection<Zug> ermittleGueltigeZuege(Stellung stellung);

	/**
	 * Liefert zuruck, ob der Konig der angegebenen Farbe angegriffen ist, also
	 * im Schach steht.
	 * 
	 * @param stellung
	 * @param farbe
	 * 
	 * @return true im Falle eines Schachs
	 */
	boolean aufSchachPruefen(Stellung stellung, Farbe farbe);

	/**
	 * Liefert zuruck, ob die ubergebene Stellung ein Matt ist, also der
	 * aktuellen Spieler am Zug im Schach steht und kein Zug ihn aus diesem
	 * Angriff fuhrt. Eine solche Spielsituation ist fur den Spiel am Zug
	 * verloren ("Schach Matt").
	 * 
	 * @param stellung
	 * 
	 * @return true im Falle eines Schach Matt
	 */
	boolean aufMattPruefen(Stellung stellung);

	/**
	 * Liefert zuruck, ob die ubergebene Stellung ein Patt ist, also der
	 * aktuelle Spieler keinen gultigen Zug hat, aber nicht im Schach steht.
	 * Eine solche Spielsituation wird Remis gewertet.
	 * 
	 * @param stellung
	 * 
	 * @return true im Falle eines Schach Matt
	 */
	boolean aufPattPruefen(Stellung stellung);

}
